Module buffer

Module buffer 

Structs

BufferGuard
BufferReadGuard
BufferRef
BufferRef: lightweight handle (id, label, usage, size). No CPU data owned.
CheckedBufferGuard
Similar to BufferGuard, but performs a change check on drop and only updates version if data has actually changed. Only useful for small buffers (uniforms etc.) where the change check is cheaper than always incrementing version.
CpuBuffer

Traits

GpuData