CheckedBufferGuard

Struct CheckedBufferGuard 

pub struct CheckedBufferGuard<'a, T: GpuData + Clone + PartialEq> { /* private fields */ }
Similar to BufferGuard, but performs a change check on drop and only updates version if data has actually changed. Only useful for small buffers (uniforms etc.) where the change check is cheaper than always incrementing version.